@@ -3,7 +3,7 @@ package DateTime::Format::Strptime;
 use strict;
 use warnings;
 
-our $VERSION = '1.68';
+our $VERSION = '1.70';
 
 use Carp qw( carp croak );
 use DateTime 1.00;
@@ -21,6 +21,7 @@ use Package::DeprecationManager 0.15 -deprecations => {
 
 our @EXPORT_OK = qw( strftime strptime );
 
+## no critic (ValuesAndExpressions::ProhibitConstantPragma)
 use constant PERL_58 => $] < 5.010;
 
 {
@@ -81,8 +82,9 @@ use constant PERL_58 => $] < 5.010;
         # Forces a check that the pattern is valid
         $self->_parser;
 
-        binmode STDERR, ':encoding(UTF-8)'
-            if $self->{debug};
+        if ( $self->{debug} ) {
+            binmode STDERR, ':encoding(UTF-8)' or die $!;
+        }
 
         return $self;
     }
@@ -333,14 +335,14 @@ sub _build_parser {
     }
 
     return {
-        regex  => qr/(?:\A\s|\b)*$regex/,
+        regex  => qr/(?:\A|\b)$regex(\b|\Z)/,
         fields => \@fields,
     };
 }
 
 {
-    my $d                 = qr/(?:[0-9])/;
-    my $one_or_two_digits = qr/[0-9 ]?$d/;
+    my $digit             = qr/(?:[0-9])/;
+    my $one_or_two_digits = qr/[0-9 ]?$digit/;
 
     # These patterns are all locale-independent. There are a few that depend
     # on the locale, and must be re-calculated for each new parser object.
@@ -361,7 +363,7 @@ sub _build_parser {
             field => 'iso_week_year_100',
         },
         G => {
-            regex => qr/$d{4}/,
+            regex => qr/$digit{4}/,
             field => 'iso_week_year',
         },
         H => {
@@ -373,7 +375,7 @@ sub _build_parser {
             field => 'hour_12',
         },
         j => {
-            regex => qr/$d{1,3}/,
+            regex => qr/$digit{1,3}/,
             field => 'day_of_year',
         },
         m => {
@@ -392,7 +394,7 @@ sub _build_parser {
             field => 'time_zone_name',
         },
         s => {
-            regex => qr/$d+/,
+            regex => qr/$digit+/,
             field => 'epoch',
         },
         S => {
@@ -420,15 +422,15 @@ sub _build_parser {
             field => 'year_100',
         },
         Y => {
-            regex => qr/$d{4}/,
+            regex => qr/$digit{4}/,
             field => 'year',
         },
         z => {
-            regex => qr/[+-]$d{4}/,
+            regex => qr/(?:Z|[+-]$digit{2}(?:[:]?$digit{2})?)/,
             field => 'time_zone_offset',
         },
         Z => {
-            regex => qr/[a-zA-Z]{1,6}|[\-\+][0-9]{2}/,
+            regex => qr/[a-zA-Z]{1,6}|[\-\+]$digit{2}/,
             field => 'time_zone_abbreviation',
         },
     );
@@ -558,6 +560,7 @@ sub _token_re_for {
         year_100
     );
 
+    ## no critic (Subroutines::ProhibitExcessComplexity)
     sub _munge_args {
         my $self = shift;
         my $args = shift;
@@ -604,8 +607,16 @@ sub _token_re_for {
         }
 
         if ( $args->{time_zone_offset} ) {
-            $args->{time_zone} = DateTime::TimeZone->new(
-                name => $args->{time_zone_offset} );
+            my $offset = $args->{time_zone_offset};
+
+            if ( $offset eq 'Z' ) {
+                $offset = '+0000';
+            }
+            elsif ( $offset =~ /^[+-][0-9]{2}$/ ) {
+                $offset .= '00';
+            }
+
+            $args->{time_zone} = DateTime::TimeZone->new( name => $offset );
         }
 
         if ( defined $args->{time_zone_abbreviation} ) {
@@ -699,6 +710,7 @@ sub _token_re_for {
     }
 }
 
+## no critic (Subroutines::ProhibitExcessComplexity)
 sub _check_dt {
     my $self = shift;
     my $dt   = shift;
@@ -867,6 +879,7 @@ sub _check_dt {
 
     return 1;
 }
+## use critic
 
 sub pattern {
     my $self = shift;
@@ -1041,7 +1054,7 @@ DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.68
+version 1.70
 
 =head1 SYNOPSIS
 
@@ -1203,14 +1216,18 @@ The % character.
 
 =item * %a or %A
 
-The weekday name according to the current locale, in abbreviated form or
+The weekday name according to the given locale, in abbreviated form or
 the full name.
 
 =item * %b or %B or %h
 
-The month name according to the current locale, in abbreviated form or
+The month name according to the given locale, in abbreviated form or
 the full name.
 
+=item * %c
+
+The datetime format according to the given locale.
+
 =item * %C
 
 The century number (0-99).
@@ -1266,10 +1283,10 @@ Arbitrary whitespace.
 
 Nanoseconds. For other sub-second values use C<%[number]N>.
 
-=item * %p
+=item * %p or %P
 
-The equivalent of AM or PM according to the locale in use. (See
-L<DateTime::Locale>)
+The equivalent of AM or PM according to the locale in use. See
+L<DateTime::Locale>.
 
 =item * %r
 
@@ -1314,6 +1331,14 @@ The weekday number (0-6) with Sunday = 0.
 The week number with Monday the first day of the week (0-53). The first
 Monday of January is the first day of week 1.
 
+=item * %x
+
+The date format according to the given locale.
+
+=item * %X
+
+The time format according to the given locale.
+
 =item * %y
 
 The year within century (0-99). When a century is not otherwise specified
@@ -1362,13 +1387,12 @@ C<bug-datetime-format-strptime@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>. I will be notified, and then you'll automatically be
 notified of progress on your bug as I make changes.
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-Format-Strptime>
-(or L<bug-datetime-format-strptime@rt.cpan.org|mailto:bug-datetime-format-strptime@rt.cpan.org>).
+Bugs may be submitted through L<https://github.com/houseabsolute/DateTime-Format-Strptime/issues>.
 
 There is a mailing list available for users of this distribution,
 L<mailto:datetime@perl.org>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
 
 =head1 DONATIONS
 
@@ -1403,12 +1427,16 @@ Rick Measham <rickm@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords D. Ilmari Mannsåker key-amb
+=for stopwords Christian Hansen D. Ilmari Mannsåker key-amb
 
 =over 4
 
 =item *
 
+Christian Hansen <chansen@cpan.org>
+
+=item *
+
 D. Ilmari Mannsåker <ilmari.mannsaker@net-a-porter.com>
 
 =item *
@@ -1417,7 +1445,7 @@ key-amb <yasutake.kiyoshi@gmail.com>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2015 - 2016 by Dave Rolsky.
 
